#pragma once
#include <score/command/Command.hpp>

#include <score_plugin_deviceexplorer_export.h>
namespace Explorer
{
namespace Command
{
SCORE_PLUGIN_DEVICEEXPLORER_EXPORT
const CommandGroupKey& DeviceExplorerCommandFactoryName();
}
}
